==> haskell-xml-hamlet-0.4.1.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-hamlet
version: 0.4.1.1
id: xml-hamlet-0.4.1.1-EBy3EvM3bNF2OGb5yjDK5m
key: xml-hamlet-0.4.1.1-EBy3EvM3bNF2OGb5yjDK5m
license: BSD3
maintainer: michael@snoyman.com
homepage: http://www.yesodweb.com/
synopsis: Hamlet-style quasiquoter for XML content
description:
    Hamlet-style quasiquoter for XML content
category: Text
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Text.Hamlet.XML
hidden-modules: Text.Hamlet.XMLParse
abi: 4f2e3a427504d518a233f9a6b20fd007
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/xml-hamlet-0.4.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/xml-hamlet-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/xml-hamlet-0.4.1.1
hs-libraries: HSxml-hamlet-0.4.1.1-EBy3EvM3bNF2OGb5yjDK5m
depends:
    base-4.10.0.0 shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi
    xml-conduit-1.6.0-F5S5bF0qUyLelzQQgHOtm
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz template-haskell-2.12.0.0
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh containers-0.5.10.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi=5b0146feaa47ba68d8065943ed5853bc
             xml-conduit-1.6.0-F5S5bF0qUyLelzQQgHOtm=d68311a22f18e80895f9913dd3408b62
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
haddock-interfaces: /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html: /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-hamlet-0.4.1.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-hamlet
version: 0.4.1.1
id: xml-hamlet-0.4.1.1-JZZodh6sItM52gIKeNYgWg
key: xml-hamlet-0.4.1.1-JZZodh6sItM52gIKeNYgWg
license: BSD3
maintainer: michael@snoyman.com
homepage: http://www.yesodweb.com/
synopsis: Hamlet-style quasiquoter for XML content
description:
    Hamlet-style quasiquoter for XML content
category: Text
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Text.Hamlet.XML
hidden-modules: Text.Hamlet.XMLParse
abi: 6dab794b3fe9eeb5de8d1fcf7a9d92a5
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/xml-hamlet-0.4.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/xml-hamlet-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/xml-hamlet-0.4.1.1
hs-libraries: HSxml-hamlet-0.4.1.1-JZZodh6sItM52gIKeNYgWg
depends:
    base-4.10.0.0 shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi
    xml-conduit-1.6.0-62u0Ld0g8V2oBOe0ChvET
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz template-haskell-2.12.0.0
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh containers-0.5.10.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi=5b0146feaa47ba68d8065943ed5853bc
             xml-conduit-1.6.0-62u0Ld0g8V2oBOe0ChvET=2bccb95a7de00653c043eff4c949c174
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
haddock-interfaces: /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html: /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
